@@ -23,7 +23,7 @@ config_variable_map <- list(
   token = "DATABRICKS_TOKEN",
   insecure = "DATABRICKS_INSECURE"
 )
-  
+
 databricks_config_as_env <- function(config) {
   if (config$config_source != "cfgfile") { # pass the auth info via environment vars
     res <- config[!is.na(config)]
@@ -98,27 +98,62 @@ get_databricks_config <- function(profile) {
   config
 }
 
+#' @return A list of tags to be set by the run context when creating MLflow runs in the
+#' current Databricks Notebook environment
+build_context_tags_from_databricks_notebook_info <- function(notebook_info) {
+  tags <- list()
+  tags[[MLFLOW_DATABRICKS_TAGS$MLFLOW_DATABRICKS_NOTEBOOK_ID]] <- notebook_info$id
+  tags[[MLFLOW_DATABRICKS_TAGS$MLFLOW_DATABRICKS_NOTEBOOK_PATH]] <- notebook_info$path
+  tags[[MLFLOW_DATABRICKS_TAGS$MLFLOW_DATABRICKS_WEBAPP_URL]] <- notebook_info$webapp_url
+  tags[[MLFLOW_TAGS$MLFLOW_SOURCE_NAME]] <- notebook_info$path
+  tags[[MLFLOW_TAGS$MLFLOW_SOURCE_VERSION]] <- get_source_version()
+  tags[[MLFLOW_TAGS$MLFLOW_SOURCE_TYPE]] <- MLFLOW_SOURCE_TYPE$NOTEBOOK
+  tags
+}
+
+#' @return A list of tags to be set by the run context when creating MLflow runs in the
+#' current Databricks Job environment
+build_context_tags_from_databricks_job_info <- function(job_info) {
+  tags <- list()
+  tags[[MLFLOW_DATABRICKS_TAGS$MLFLOW_DATABRICKS_JOB_ID]] <- job_info$job_id
+  tags[[MLFLOW_DATABRICKS_TAGS$MLFLOW_DATABRICKS_JOB_RUN_ID]] <- job_info$run_id
+  tags[[MLFLOW_DATABRICKS_TAGS$MLFLOW_DATABRICKS_JOB_TYPE]] <- job_info$job_type
+  tags[[MLFLOW_DATABRICKS_TAGS$MLFLOW_DATABRICKS_WEBAPP_URL]] <- job_info$webapp_url
+  tags[[MLFLOW_TAGS$MLFLOW_SOURCE_NAME]] <- paste(
+    "jobs", job_info$job_id, "run", job_info$run_id, sep = "/"
+  )
+  tags[[MLFLOW_TAGS$MLFLOW_SOURCE_VERSION]] <- get_source_version()
+  tags[[MLFLOW_TAGS$MLFLOW_SOURCE_TYPE]] <- MLFLOW_SOURCE_TYPE$JOB
+  tags
+}
+
 mlflow_get_run_context.mlflow_databricks_client <- function(client, experiment_id, ...) {
   if (exists(".databricks_internals")) {
-    notebook_info <- do.call(".get_notebook_info", list(), envir = get(".databricks_internals",
-                                                                       envir = .GlobalEnv))
+    databricks_internal_env <- get(".databricks_internals", envir = .GlobalEnv)
+    notebook_info <- do.call(".get_notebook_info", list(), envir = databricks_internal_env)
     if (!is.na(notebook_info$id) && !is.na(notebook_info$path)) {
-      tags <- list()
-      tags[[MLFLOW_DATABRICKS_TAGS$MLFLOW_DATABRICKS_NOTEBOOK_ID]] <- notebook_info$id
-      tags[[MLFLOW_DATABRICKS_TAGS$MLFLOW_DATABRICKS_NOTEBOOK_PATH]] <- notebook_info$path
-      tags[[MLFLOW_DATABRICKS_TAGS$MLFLOW_DATABRICKS_WEBAPP_URL]] <- notebook_info$webapp_url
-      tags[[MLFLOW_TAGS$MLFLOW_SOURCE_NAME]] <- notebook_info$path
-      tags[[MLFLOW_TAGS$MLFLOW_SOURCE_VERSION]] <- get_source_version()
-      tags[[MLFLOW_TAGS$MLFLOW_SOURCE_TYPE]] <- MLFLOW_SOURCE_TYPE$NOTEBOOK
-      list(
+      return(list(
         client = client,
-        tags = tags,
+        tags = build_context_tags_from_databricks_notebook_info(notebook_info),
         experiment_id = experiment_id %||% notebook_info$id,
         ...
-      )
-    } else {
-      NextMethod()
+      ))
     }
+
+    job_info <- if (exists(".get_job_info", envir = databricks_internal_env)) {
+      do.call(".get_job_info", list(), envir = databricks_internal_env)
+    } else {
+      NA
+    }
+    if (!is.na(job_info) && !is.na(job_info$job_id)) {
+      return(list(
+        client = client,
+        tags = build_context_tags_from_databricks_job_info(job_info),
+        experiment_id = experiment_id %||% 0,
+        ...
+      ))
+    }
+    NextMethod()
   } else {
     NextMethod()
   }
@@ -129,6 +164,13 @@ MLFLOW_DATABRICKS_TAGS <- list(
   MLFLOW_DATABRICKS_NOTEBOOK_PATH = "mlflow.databricks.notebookPath",
   MLFLOW_DATABRICKS_WEBAPP_URL = "mlflow.databricks.webappURL",
   MLFLOW_DATABRICKS_RUN_URL = "mlflow.databricks.runURL",
+  # The SHELL_JOB_ID and SHELL_JOB_RUN_ID tags are used for tracking the
+  # Databricks Job ID and Databricks Job Run ID associated with an MLflow Project run
   MLFLOW_DATABRICKS_SHELL_JOB_ID = "mlflow.databricks.shellJobID",
-  MLFLOW_DATABRICKS_SHELL_JOB_RUN_ID = "mlflow.databricks.shellJobRunID"
+  MLFLOW_DATABRICKS_SHELL_JOB_RUN_ID = "mlflow.databricks.shellJobRunID",
+  # The JOB_ID, JOB_RUN_ID, and JOB_TYPE tags are used for automatically recording Job
+  # information when MLflow Tracking APIs are used within a Databricks Job
+  MLFLOW_DATABRICKS_JOB_ID = "mlflow.databricks.jobID",
+  MLFLOW_DATABRICKS_JOB_RUN_ID = "mlflow.databricks.jobRunID",
+  MLFLOW_DATABRICKS_JOB_TYPE = "mlflow.databricks.jobType"
 )
