@@ -69,7 +69,7 @@ class __MLflowPLCallback(pl.Callback, metaclass=ExceptionSafeAbstractClass):
         # pytorch-lightning runs a few steps of validation in the beginning of training
         # as a sanity check to catch bugs without having to wait for the training routine
         # to complete. During this check, we should skip logging metrics.
-        # https://pytorch-lightning.readthedocs.io/en/stable/common/trainer.html#num-sanity-val-steps # noqa
+        # https://pytorch-lightning.readthedocs.io/en/stable/common/trainer.html#num-sanity-val-steps
         sanity_checking = (
             # `running_sanity_check` has been renamed to `sanity_checking`:
             # https://github.com/PyTorchLightning/pytorch-lightning/pull/9209
@@ -127,7 +127,7 @@ class __MLflowPLCallback(pl.Callback, metaclass=ExceptionSafeAbstractClass):
             # If validation loop is enabled (meaning `validation_step` is overridden),
             # log metrics in `on_validaion_epoch_end` to avoid logging the same metrics
             # records twice
-            if trainer.disable_validation:
+            if not trainer.enable_validation:
                 self._log_metrics(trainer, pl_module)
 
         @rank_zero_only
@@ -311,7 +311,14 @@ def patched_fit(original, self, *args, **kwargs):
         shutil.rmtree(tempdir)
 
     if log_models:
-        mlflow.pytorch.log_model(pytorch_model=self.model, artifact_path="model")
+        registered_model_name = get_autologging_config(
+            mlflow.pytorch.FLAVOR_NAME, "registered_model_name", None
+        )
+        mlflow.pytorch.log_model(
+            pytorch_model=self.model,
+            artifact_path="model",
+            registered_model_name=registered_model_name,
+        )
 
         if early_stop_callback is not None and self.checkpoint_callback.best_model_path:
             mlflow.log_artifact(
