@@ -206,13 +206,13 @@ def log_explanation(predict_function, features, artifact_path=None):
 
         import numpy as np
         import pandas as pd
-        from sklearn.datasets import load_boston
+        from sklearn.datasets import load_diabetes
         from sklearn.linear_model import LinearRegression
 
         import mlflow
 
         # prepare training data
-        dataset = load_boston()
+        X, y = dataset = load_diabetes(return_X_y=True, as_frame=True)
         X = pd.DataFrame(dataset.data[:50, :8], columns=dataset.feature_names[:8])
         y = dataset.target[:50]
 
@@ -409,7 +409,8 @@ def save_explainer(
 
     if os.path.exists(path):
         raise MlflowException(
-            message="Path '{}' already exists".format(path), error_code=RESOURCE_ALREADY_EXISTS,
+            message="Path '{}' already exists".format(path),
+            error_code=RESOURCE_ALREADY_EXISTS,
         )
 
     os.makedirs(path)
@@ -473,13 +474,17 @@ def save_explainer(
             # To ensure `_load_pyfunc` can successfully load the model during the dependency
             # inference, `mlflow_model.save` must be called beforehand to save an MLmodel file.
             inferred_reqs = mlflow.models.infer_pip_requirements(
-                path, FLAVOR_NAME, fallback=default_reqs,
+                path,
+                FLAVOR_NAME,
+                fallback=default_reqs,
             )
             default_reqs = sorted(set(inferred_reqs).union(default_reqs))
         else:
             default_reqs = None
         conda_env, pip_requirements, pip_constraints = _process_pip_requirements(
-            default_reqs, pip_requirements, extra_pip_requirements,
+            default_reqs,
+            pip_requirements,
+            extra_pip_requirements,
         )
     else:
         conda_env, pip_requirements, pip_constraints = _process_conda_env(conda_env)
